on xenial help sign in
Do the same, just faster

With this patch the test_search AP test goes from 44s to 34s

commit081bdc10d8e2350e356c2c0f335af03ab026b391 authorAlbert Astals Cid <albert.astals@canonical.com> dateThu 21 Apr 2016, 16:22 (11 years ago) parentab21d91
1 file changed+2−3
tests/autopilot/unity8/dash.py+2−3
tests/autopilot/unity8/dash.py+2−3
@@ -175,9 +175,8 @@ class Dash(ubuntuuitoolkit.UbuntuUIToolkitCustomProxyObjectBase):
175175 return page_header.select_single(objectName='searchTextField')
176176
177177 def _get_current_page_header(self):
178− dashContentList = self.select_single(objectName="dashContentList")
179− all_headers = dashContentList.select_many("QQuickLoader")
180− for i in all_headers:
178+ all_scopes = self.dash_content_list.select_many("GenericScopeView")
179+ for i in all_scopes:
181180 if i.isCurrent:
182181 return i.select_single(objectName="scopePageHeader")
183182 return None